function output = DeltaAlphaPy_CoGdSS(g1rn, g2, t0real, t0imag, d2, Lsf, LJ, rho)
%DELTAALPHA computes the Gilbert damping parameter enhnancement due to 
%spin pumping into a CoGd spin sink,
% from Eq. 16 in Taniguchi et al. IEEE Trans. Magn. 44, 2636 (2008)
%   g1rn = renormalized spin mixing conductance at Py/Cu interface (nm^-2)
%   g2 = spin mixing conductance at Cu/CoGd interface (nm^-2)
%   t0 = interfacial contribution to transmission mixing conductance
%   (nm^-2)
%   d2 = FM spin sink thickness (nm)
%   Lsf = transverse spin flip length (nm)
%   LJ = spin dephasing length (nm)
%   rho = resistivity of FM spin sink (Ohm m)

Ms = 800e3; % saturation magnetization of the spin source (A/m)
d1 = 7e-9; % thickness of the spin source (m)
g = 2.1; % g-factor of the spin source
muB = 9.27e-24; % bohr magneton (J/T)


g2rn = g2renorm(g2, t0real, t0imag, d2, Lsf, LJ, rho);
g2rn = g2rn*1e18; % convert from nm^-2 to m^-2

g1rn = g1rn*1e18; % convert from nm^-2 to m^-2

output = g*muB/(4*pi*Ms*d1)./(1./g1rn+1./g2rn);


end

