function complexVal = eta(d2, Lsf, LJ, rho)
% "eta" defined below Eq. 11 in Taniguchi et al. IEEE Trans. Magn. 44, 2636 (2008)

%   d2 = FM spin sink thickness (nm)
%   Lsf = transverse spin flip length (nm)
%   LJ = spin dephasing length (nm)
%   rho = resistivity of FM spin sink (Ohm m)

%  output (complexVal) in nm^2

h = 6.626e-34; % Planck's constant (J s)
e = 1.602e-19; % electron charge (C)

Lp = Lplus(Lsf, LJ)*1e-9; % convert from nm to m
d2 = d2*1e-9; % convert from nm to m

complexVal = (h./(2*e^2*rho.*Lp).*tanh(d2./Lp)).^-1;
complexVal = complexVal*1e18;

end

