function g2rn = g2renorm(g2, t0real, t0imag, d2, Lsf, LJ, rho)
%G2RENORM computes the renormalized spin-mixing conductance at the Cu/FM2
%interface, which depends on the ratio d2/Lplus 
% from Eq. 10-12 in Taniguchi et al. IEEE Trans. Magn. 44, 2636 (2008)
%   g2 = spin mixing conductance at Cu/FM2 interface (nm^-2)
%   t0 = interfacial contribution to transmission mixing conductance
%   (nm^-2)
%   d2 = FM spin sink thickness (nm)
%   Lsf = transverse spin flip length (nm)
%   LJ = spin dephasing length (nm)
%   rho = resistivity of FM spin sink (Ohm m)

%  output (g2rn) in nm^-2

K_1 = K1(t0real, t0imag, d2, Lsf, LJ, rho);
K_2 = K2(t0real, t0imag, d2, Lsf, LJ, rho);

g2rn = K_1./(K_1.^2+K_2.^2).*g2;

end

